@@ -169,7 +169,7 @@ where
     idcs: Arc<Mutex<VecDeque<usize>>>,
     current_split: Split,
     fill_thread: Option<thread::JoinHandle<Result<()>>>,
-    out_receiver: Option<Receiver<Sample<T>>>,
+    out_receiver: Option<Receiver<Result<Sample<T>>>>,
     overfit: bool,
 }
 
@@ -329,7 +329,7 @@ where
                 // To make sure, we get the samples in the correct order, we could add another
                 // ordering index and some kind of cache to use in get_batch().
                 |(), idx| -> Result<()> {
-                    let sample = ds.get_sample(idx)?;
+                    let sample = ds.get_sample(idx);
                     if let Err(e) = out_sender.send(sample) {
                         return Err(DfDatasetError::SendError(e.to_string()));
                     }
@@ -399,7 +399,7 @@ where
                     tries += 1;
                     continue 'outer;
                 }
-                Ok(s) => samples.push(s),
+                Ok(s) => samples.push(s?),
             }
             i += 1;
             tries = 0;
@@ -714,10 +714,10 @@ impl<'a> DatasetBuilder<'a> {
             if (!path.is_file())
                 || match path.read_link() {
                     Err(_) => false,
-                    Ok(p) => p.is_file(),
+                    Ok(p) => !p.is_file(),
                 }
             {
-                eprintln!("Dataset {} not found. Skipping.", name);
+                eprintln!("Dataset {:?} not found. Skipping.", path);
                 continue;
             }
             let ds = Hdf5Dataset::new(path.to_str().unwrap())?;
@@ -1171,7 +1171,12 @@ fn get_dstype(file: &File) -> Option<DsType> {
 
 impl Hdf5Dataset {
     fn new(path: &str) -> Result<Self> {
-        let file = File::open(path)?;
+        let file = File::open(path).map_err(move |e: hdf5::Error| -> DfDatasetError {
+            DfDatasetError::Hdf5ErrorDetail {
+                source: e,
+                msg: format!("Error during File::open of dataset {}", path),
+            }
+        })?;
         match get_dstype(&file) {
             None => Err(DfDatasetError::Hdf5DsTypeNotFoundError),
             Some(dstype) => {
@@ -1589,7 +1594,6 @@ mod tests {
                 sr as u32,
                 1,
             )?;
-            break;
         }
         loader.start_epoch("train", 2)?;
         for i in 0..2 {
